/*
   deckmate.h - header file for the deckmate C source files.

   Author: Paul Hardy, June 2020

   Copyright (C) 2020 Paul Hardy

   LICENSE:

      This program is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
      the Free Software Foundation, either version 2 of the License, or
      (at your option) any later version.

      This program is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
      GNU General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _DECKMATE_H_
#define _DECKMATE_H_

/*
   Define the nominal paper size as U.S. letter,
   measuring 8.5 inches by 11 inches.  This is
   converted into PostScript points (72 points
   per inch), for 612 pt by 792 pt.
*/
#define PAPER_WIDTH  612
#define PAPER_HEIGHT 792

/*
   Width and height of one character, in points.
*/
#define CHAR_WIDTH   6
#define CHAR_HEIGHT 10

/*
   Margins of the box that encloses an 80-column listing.
   Set values for U.S. letter paper (8.5" by 11") in
   portrait orientation.  A4 paper is about 6 mm narrower,
   which will still fit within the bounding box below.
*/
#define   BOX_WIDTH_80	((int)(80*CHAR_WIDTH))                     /* 480 pt */
#define  BOX_HEIGHT_80	((int)(66*CHAR_HEIGHT + 2))                /* 662 pt */
#define LEFT_MARGIN_80	((int)((PAPER_WIDTH  - BOX_WIDTH_80) / 2)) /*  66 pt */
#define  TOP_MARGIN_80	((int)(6*CHAR_HEIGHT + BOX_HEIGHT_80 - 2)) /* 720 pt */
#define PAGE_MIDDLE_80	((int)(LEFT_MARGIN_80 + BOX_WIDTH_80 / 2)) /* 306 pt */

/*
   Approximate scale for wide printing (132 columns)
   in landscape mode.
*/
#define WIDE_SCALE 0.75

/*
   Margins of the box that encloses a 132-column listing.
   Set values for U.S. legal paper (8.5" by 14") in
   landscape orientation.  British foolscap paper is
   0.5" narrower (about 13 mm narrower), which will
   still fit within the bounding box below.  It will
   also fit on A3 paper.
*/
#define  TOP_MARGIN_132	TOP_MARGIN_80
#define   BOX_WIDTH_132	(132 * CHAR_WIDTH)  /* 792 points */
#define  BOX_HEIGHT_132	BOX_HEIGHT_80
#define LEFT_MARGIN_132	((int)((PAPER_HEIGHT / WIDE_SCALE - BOX_WIDTH_132) / 2)) /* 132 pt */
#define PAGE_MIDDLE_132 ((int)(LEFT_MARGIN_132 + BOX_WIDTH_132/2)) /* 528 pt */

/*
   Maximum number of characters to accept
   in an input line, including the final
   <CR><LF><NUL> sequence.
*/
#define MAXBUFFER 135

/*
   Maximum size of a file title passed to PostScript output.
*/
#define MAXTITLE 200

/*
   RGB values for PostScript.  Range for each is 0.0 to 1.0.
*/
struct ps_rgb {
   float red, green, blue;
};

/*
   Language templates for printing column headers & vertical lines on form.
*/
typedef enum {LANG_NONE, LANG_FORTRAN, LANG_COBOL, LANG_RPG} language;

#define FONT_PS_COURIER		0x01
#define FONT_PS_HELVETICA	0x02
#define FONT_PS_SYMBOL		0x04

#endif  /* _DECMATE_H_ */

